@@ -1,8 +1,6 @@
 # your package information
-import config
-
 name = "greendeck-redis"
-__version__ = config.get_greendeck_redis_version()
+__version__ = "1.0.3"
 author = "Yashvardhan Srivastava"
 author_email = "yash@greendeck.co"
 url = ""
